/*

Tennessee Traffic Cams v2.0

Authored by Cale Mooth
cale@midnightcheese.com
http://tncam.midnightcheese.com/

*/

// Global variables for the info and done buttons; keeping these around lets us modify them later
var glassDoneButton;
var whiteInfoButton;

var currentImage = widget.preferenceForKey("currentCam");
var theCity = widget.preferenceForKey("currentCity");
var theLocation = widget.preferenceForKey("currentCamLocation");
var cameraXml;
var currentTime = new Date();
var currentVersion;
var thisVersion = 2.0;

// var currentImage;
// var theCity;
// var theLocation;

function buildCitySelect() {
  $.ajax({  
    type: "GET",
    //url: "cameras.xml",
    url: "http://tncam.midnightcheese.com/xml/cameras.xml",  
    dataType: "xml",
    success: function(xml){
      cameraXml = xml;
      checkForUpdates();
      $("#citySelect").empty();
      $("#cameraSelect").empty();
      $(xml).find('city').each(function(){
        city = $(this).attr("name");
        $("#citySelect").append('<option value="'+city+'">'+city+'</option>')
      });
      if (theCity==null) {
        theCity = $("#citySelect option:selected").attr('value');
      }
      $(xml).find('city').each(function(){
        if ($(this).attr("name") == theCity) {
          $(this).find("route").each(function() {
            route = $(this).attr("name");
            $("#cameraSelect").append('<optgroup label="'+theCity+' '+route+'">');
            $(this).find("camera").each(function() {
              cameraname = $(this).attr("name");
              cameraurl = $(this).find('url').text();
              $("#cameraSelect").append('<option value="'+cameraurl+'">'+cameraname+'</option>');
            });
          });
        }
      });
      $("#cameraSelect").prepend('<option value="null">Select a camera...</option>');
      $('#citySelect option[value="'+theCity+'"]').attr('selected','selected');
      if (currentImage != null)
        $('#cameraSelect option[value="'+currentImage+'"]').attr('selected','selected')
    }  
  });
}

function populateCameras() {
  theCity = $("#citySelect option:selected").attr('value');
  if (theCity == null) {
    theCity = "Brentwood";
  }
  widget.setPreferenceForKey(theCity,"currentCity");
  
  $("#cameraSelect").empty();
  $(cameraXml).find('city').each(function(){
    if ($(this).attr("name") == theCity) {
      $(this).find("route").each(function() {
        route = $(this).attr("name");
        $("#cameraSelect").append('<optgroup label="'+theCity+' '+route+'">');
        $(this).find("camera").each(function() {
          cameraname = $(this).attr("name");
          cameraurl = $(this).find('url').text();
          $("#cameraSelect").append('<option value="'+cameraurl+'">'+cameraname+'</option>');
        });
      });
    }
  });
  $("#cameraSelect").prepend('<option value="null">Select a camera...</option>');
}

function changeCamera() {
  currentTime = new Date();
  currentImage = $("#cameraSelect option:selected").attr('value');
  theLocation = $("#cameraSelect option:selected").text();
  widget.setPreferenceForKey(currentImage,"currentCam");
  widget.setPreferenceForKey(theLocation,"currentCamLocation");
  
  $("#image").empty();
  $("#city").empty();
  $("#camera").empty();

  if (theCity == 'Brentwood' || theCity == 'Murfreesboro') {
    $("#image").append("<iframe src='"+currentImage+"?time=" + escape(new Date()) + "' width='320' height='240' scrolling='no' frameborder='no'>");
    $("#city").append(theCity);
    $("#camera").append(theLocation);
  } else {
    $("#image").append('<img src="'+currentImage+'?time='+currentTime.getTime()+'" width="320" height="240" border="0" />');
    $("#city").append(theCity);
    $("#camera").append(theLocation);
  }
}

function checkForUpdates() {
  currentVersion = $(cameraXml).find('version').text();
  alert(currentVersion);
  if (currentVersion > thisVersion) {
    $("#upgrade").css("display","block");
  }

  if (currentVersion == thisVersion) {
    $("#upgrade").css("display","none");
  }
}

// setup() is the onload handler for the widget. It calls constructors for the AppleInfoButton
// and AppleGlassButton classes that populate existing divs with their respective controls

function setup() {
  buildCitySelect();
  currentTime = new Date();
  glassDoneButton = new AppleGlassButton(document.getElementById("doneButton"), "Done", hidePrefs);
  whiteInfoButton = new AppleInfoButton(document.getElementById("infoButton"), document.getElementById("front"), "white", "white", showPrefs);

  if (currentImage == null)
  {
    $("#image").empty();
    $("#city").empty();
    $("#camera").empty();
    $("#image").append("<img src='http://www.tdot.state.tn.us/cctv/cctvnash/live/cam55_14.jpg' width='320' height='240' border='0' />");
    $("#city").append("Nashville");
    $("#camera").append("I-24 @ Harding");
  }else{
    $("#image").empty();
    $("#city").empty();
    $("#camera").empty();
    $("#image").append('<img src="'+currentImage+'?time='+currentTime.getTime()+'" width="320" height="240" border="0" />');
    $("#city").append(theCity);
    $("#camera").append(theLocation);
  }
}

// showPrefs() is called when the preferences flipper is clicked upon.  It freezes the front of the widget,
// hides the front div, unhides the back div, and then flips the widget over.

function showPrefs() {
  buildCitySelect();
  $('#citySelect option[value="'+theCity+'"]').attr('selected','selected');
  if (currentImage != null)
    $('#cameraSelect option[value="'+currentImage+'"]').attr('selected','selected')

  var front = document.getElementById("front");
  var back = document.getElementById("back");

  if (window.widget)
    widget.prepareForTransition("ToBack"); // freezes the widget so that you can change it without the user noticing

  front.style.display="none"; // hide the front
  back.style.display="block"; // show the back

  if (window.widget)
    setTimeout ('widget.performTransition();', 0); // and flip the widget over	
}

// hidePrefs() is called by the done button on the back side of the widget.  It performs the opposite transition
// as showPrefs() does.

function hidePrefs() {
  var front = document.getElementById("front");
  var back = document.getElementById("back");

  if (window.widget)
    widget.prepareForTransition("ToFront"); // freezes the widget and prepares it for the flip back to the front

  back.style.display="none";    // hide the back
  front.style.display="block";  // show the front

  if (window.widget)
    setTimeout ('widget.performTransition();', 0); // and flip the widget back to the front
}

function show() {
  $("#image").empty();
  $("#city").empty();
  $("#camera").empty();
  currentTime = new Date();

  if (currentImage == null) {
    $("#image").append("<img src='http://www.tdot.state.tn.us/cctv/cctvnash/live/cam55_14.jpg' width='320' height='240' border='0' />");
    $("#city").append("Nashville");
    $("#camera").append("I-24 @ Harding");
  }else{
    if (theCity == 'Brentwood' || theCity == 'Murfreesboro') {
      $("#image").append("<iframe src='"+currentImage+"?time=" + escape(new Date()) + "' width='320' height='240' scrolling='no' frameborder='no'>");
      $("#city").append(theCity);
      $("#camera").append(theLocation);
    } else {
      $("#image").append('<img src="'+currentImage+'?time='+currentTime.getTime()+'" width="320" height="240" border="0" />');
      $("#city").append(theCity);
      $("#camera").append(theLocation);
    }
  }
}

function hide() {
  $("#image").empty();
  $("#city").empty();
  $("#camera").empty();
}

if (window.widget) {
  widget.onshow = show;
  widget.onhide = hide;
}